@@ -7,6 +7,7 @@ Created on Sun Feb 13 17:21:17 2022
 Created for Colossal Contracting, LLC.
 """
 
+import os
 from datetime import date, datetime
 from enum import Enum
 from dataclasses import dataclass
@@ -145,8 +146,11 @@ def process_track_results(json):
             latest_date = None
             latest_type = None
             events = []
-            if "dateAndTimes" not in tracking_result:
-                return TrackingResult(False)
+            if "dateAndTimes" not in tracking_result or "error" in tracking_result:
+                new_tracking_result = TrackingResult(False)
+                new_tracking_result.tracking_number = tracking_number
+                new_tracking_result.json = json
+                continue
             for event in tracking_result["dateAndTimes"]:
                 event_type = Event[event["type"]]
                 event_date = datetime.fromisoformat(event["dateTime"])
@@ -185,6 +189,8 @@ def process_track_results(json):
                 has_associated_shipments=has_associated_shipments,
                 master_tracking_number=master_tracking_number)
             tracking_results.append(new_tracking_result)
+
+    if len(tracking_results) == 0: return [TrackingResult(False)]
     return tracking_results
 
 class FedexAPI:
@@ -230,7 +236,9 @@ class FedexAPI:
         latest_date = None  # declare out of the loop scope to preserve
         latest_result = None
         for result in tracking_results:
-            if latest_result is None or result.latest_status.datetime > latest_date:
+            if latest_result is None:
+                latest_result = result
+            elif result.latest_status is not None and (latest_date is None or result.latest_status.datetime > latest_date):
                 latest_date = result.latest_status.datetime
                 latest_result = result
         return latest_result
@@ -271,3 +279,7 @@ class FedexAPI:
         _download_file(
             f"https://www.fedex.com/trackingCal/retrievePDF.jsp?accountNbr=&anon=true&appType=&destCountry=&locale=en_US&shipDate=&trackingCarrier=FDXA&trackingNumber={tracking_number}&trackingQualifier={qualifier}&type=SPOD",
             new_filename)
+        try:
+            return os.path.getfilesize(new_filename) > 10240
+        except FileNotFoundError:
+            return False
